
(_api_database)=
# Databases

## Web Databases
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.database.StandardDatabase
```

## Internal Databases
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.database.MieDatabase
```

## Solar Databases
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.solar.SolarModel
```
